@@ -83,13 +83,6 @@ class FibreChannelConnector(base.BaseLinuxConnector):
         else:
             wwns = []
 
-        # Convert wwns to lower case
-        wwns = [wwn.lower() for wwn in wwns]
-        if target_wwns:
-            connection_properties['target_wwns'] = wwns
-        elif target_wwn:
-            connection_properties['target_wwn'] = wwns
-
         target_lun = connection_properties.get('target_lun', 0)
         target_luns = connection_properties.get('target_luns')
         if target_luns:
@@ -123,13 +116,8 @@ class FibreChannelConnector(base.BaseLinuxConnector):
             wwpn_lun_map[wwpn] = lun
 
         # If there is an initiator_target_map we can update it too
-        if connection_properties.get('initiator_target_map') is not None:
-            # Convert it to lower case
+        if 'initiator_target_map' in connection_properties:
             itmap = connection_properties['initiator_target_map']
-            itmap = {k.lower(): [port.lower() for port in v]
-                     for k, v in itmap.items()}
-            connection_properties['initiator_target_map'] = itmap
-
             new_itmap = dict()
             for init_wwpn in itmap:
                 target_wwpns = itmap[init_wwpn]
@@ -137,7 +125,7 @@ class FibreChannelConnector(base.BaseLinuxConnector):
                 for target_wwpn in target_wwpns:
                     if target_wwpn in wwpn_lun_map:
                         init_targets.append((target_wwpn,
-                                             wwpn_lun_map[target_wwpn]))
+                                            wwpn_lun_map[target_wwpn]))
                 new_itmap[init_wwpn] = init_targets
             connection_properties['initiator_target_lun_map'] = new_itmap
 
@@ -176,8 +164,7 @@ class FibreChannelConnector(base.BaseLinuxConnector):
 
         volume_paths = self.get_volume_paths(connection_properties)
         if volume_paths:
-            return self._linuxscsi.extend_volume(
-                volume_paths, use_multipath=self.use_multipath)
+            return self._linuxscsi.extend_volume(volume_paths)
         else:
             LOG.warning("Couldn't find any volume paths on the host to "
                         "extend volume for %(props)s",
@@ -205,14 +192,13 @@ class FibreChannelConnector(base.BaseLinuxConnector):
             connection_properties)
 
         hbas = self._linuxfc.get_fc_hbas_info()
+        if not hbas:
+            LOG.warning("We are unable to locate any Fibre Channel devices.")
+            raise exception.NoFibreChannelHostsFound()
+
         host_devices = self._get_possible_volume_paths(
             connection_properties, hbas)
 
-        if len(host_devices) == 0:
-            # this is empty because we don't have any FC HBAs
-            LOG.warning("We are unable to locate any Fibre Channel devices")
-            raise exception.NoFibreChannelHostsFound()
-
         # The /dev/disk/by-path/... node is not always present immediately
         # We only need to find the first device.  Once we see the first device
         # multipath will have any others.
@@ -245,10 +231,9 @@ class FibreChannelConnector(base.BaseLinuxConnector):
             _wait_for_device_discovery, host_devices)
         timer.start(interval=2).wait()
 
-        if self.host_device is not None and self.device_name is not None:
-            LOG.debug("Found Fibre Channel volume %(name)s "
-                      "(after %(tries)s rescans)",
-                      {'name': self.device_name, 'tries': self.tries})
+        LOG.debug("Found Fibre Channel volume %(name)s "
+                  "(after %(tries)s rescans.)",
+                  {'name': self.device_name, 'tries': self.tries})
 
         # find out the WWN of the device
         device_wwn = self._linuxscsi.get_scsi_wwn(self.host_device)
@@ -337,8 +322,7 @@ class FibreChannelConnector(base.BaseLinuxConnector):
         mpath_path = None
         for path in volume_paths:
             real_path = self._linuxscsi.get_name_from_path(path)
-            if (self.use_multipath and not mpath_path and
-                    self.check_valid_device(path)):
+            if self.use_multipath and not mpath_path:
                 wwn = self._linuxscsi.get_scsi_wwn(path)
                 mpath_path = self._linuxscsi.find_multipath_device_path(wwn)
                 if mpath_path:
