@@ -109,7 +109,8 @@ class ISCSIConnector(base.BaseLinuxConnector, base_iscsi.BaseISCSIConnector):
         """Get iSCSI session information as a list of tuples.
 
         Uses iscsiadm -m session and from a command output like
-            tcp: [1] 192.168.121.250:3260,1 iqn.2010-10.org.openstack:volume-
+            tcp: [1] 192.168.121.250:3260,1 iqn.2010-10.org.openstack:
+            volume- (non-flash)
 
         This method will drop the node type and return a list like this:
             [('tcp:', '1', '192.168.121.250:3260', '1',
@@ -134,7 +135,7 @@ class ISCSIConnector(base.BaseLinuxConnector, base_iscsi.BaseISCSIConnector):
     def _get_iscsi_nodes(self):
         """Get iSCSI node information (portal, iqn) as a list of tuples.
 
-        Uses iscsi_adm -m node and from a command output like
+        Uses iscsiadm -m node and from a command output like
             192.168.121.250:3260,1 iqn.2010-10.org.openstack:volume
 
         This method will drop the tpgt and return a list like this:
@@ -174,7 +175,7 @@ class ISCSIConnector(base.BaseLinuxConnector, base_iscsi.BaseISCSIConnector):
         :param connection_properties: The dictionary that describes all
                                       of the target volume attributes.
         :type connection_properties: dict
-        :param discover: Wheter doing an iSCSI discovery is acceptable.
+        :param discover: Whether doing an iSCSI discovery is acceptable.
         :type discover: bool
         :returns: list of tuples of (ip, iqn, lun)
         """
@@ -471,8 +472,7 @@ class ISCSIConnector(base.BaseLinuxConnector, base_iscsi.BaseISCSIConnector):
         volume_paths = self.get_volume_paths(connection_properties)
         LOG.info("Found paths for volume %s", volume_paths)
         if volume_paths:
-            return self._linuxscsi.extend_volume(
-                volume_paths, use_multipath=self.use_multipath)
+            return self._linuxscsi.extend_volume(volume_paths)
         else:
             LOG.warning("Couldn't find any volume paths on the host to "
                         "extend volume for %(props)s",
@@ -515,7 +515,6 @@ class ISCSIConnector(base.BaseLinuxConnector, base_iscsi.BaseISCSIConnector):
             with excutils.save_and_reraise_exception():
                 self._cleanup_connection(connection_properties, force=True)
 
-    @utils.retry(exceptions=(exception.VolumeDeviceNotFound))
     def _get_device_link(self, wwn, device, mpath):
         # These are the default symlinks that should always be there
         if mpath:
@@ -1051,7 +1050,7 @@ class ISCSIConnector(base.BaseLinuxConnector, base_iscsi.BaseISCSIConnector):
             for s in sessions:
                 # Found our session, return session_id
                 if (s[0] in self.VALID_SESSIONS_PREFIX and
-                        portal.lower() == s[2].lower() and s[4] == target_iqn):
+                        portal == s[2] and s[4] == target_iqn):
                     return s[1], manual_scan
 
             try:
