@@ -106,7 +106,7 @@ class LinuxSCSITestCase(base.TestCase):
     @mock.patch('time.sleep')
     @mock.patch('os.path.exists', return_value=True)
     def test_wait_for_volumes_removal_failure(self, exists_mock, sleep_mock):
-        retries = 61
+        retries = 3
         names = ('sda', 'sdb')
         self.assertRaises(exception.VolumePathNotRemoved,
                           self.linuxscsi.wait_for_volumes_removal, names)
@@ -221,10 +221,10 @@ class LinuxSCSITestCase(base.TestCase):
     @mock.patch.object(time, 'sleep')
     def test_wait_for_path_not_found(self, exists_mock, sleep_mock):
         path = "/dev/disk/by-id/dm-uuid-mpath-%s" % '1234567890'
-        self.assertRaisesRegexp(exception.VolumeDeviceNotFound,
-                                r'Volume device not found at %s' % path,
-                                self.linuxscsi.wait_for_path,
-                                path)
+        self.assertRaisesRegex(exception.VolumeDeviceNotFound,
+                               r'Volume device not found at %s' % path,
+                               self.linuxscsi.wait_for_path,
+                               path)
 
     @ddt.data({'do_raise': False, 'force': False},
               {'do_raise': True, 'force': True})
@@ -761,8 +761,7 @@ loop0                                     0"""
         mock_find_mpath_path.return_value = ('/dev/mapper/dm-uuid-mpath-%s' %
                                              wwn)
 
-        ret_size = self.linuxscsi.extend_volume(['/dev/fake1', '/dev/fake2'],
-                                                use_multipath=True)
+        ret_size = self.linuxscsi.extend_volume(['/dev/fake1', '/dev/fake2'])
         self.assertEqual(2048, ret_size)
 
         # because we don't mock out the echo_scsi_command
@@ -796,8 +795,7 @@ loop0                                     0"""
 
         mock_mpath_resize_map.return_value = 'fail'
 
-        ret_size = self.linuxscsi.extend_volume(['/dev/fake1', '/dev/fake2'],
-                                                use_multipath=True)
+        ret_size = self.linuxscsi.extend_volume(['/dev/fake1', '/dev/fake2'])
         self.assertIsNone(ret_size)
 
         # because we don't mock out the echo_scsi_command
